@@ -1,5 +1,5 @@
 from .settings import Settings, si, const
-from .formulae import Formulae, convert_to
+from .formulae import convert_to
 from .plot import plot
 from .arakawa_c import arakawa_c
 from .droplet_activation import DropletActivation
